bayespy.inference.vmp.nodes.expfamily.ExponentialFamily.move_plates
===================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.expfamily

.. automethod:: ExponentialFamily.move_plates